@@ -4,6 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use File::Slurp;
+use base 'Ixchel::Actions::base';
 
 =head1 NAME
 
@@ -11,17 +12,27 @@ Ixchel::Actions::suricata_extract_submit_config - Generates the config file for
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
-=head1 SYNOPSIS
+=head1 CLI SYNOPSIS
 
-    my $filled_in=$ixchel->action(action=>'suricata_extract_submit_config', opts=>{w=>1});
+ixchel -a suricata_extract_submit_config
 
-    print $filled_in;
+ixchel -a suricata_extract_submit_config B<-w> [B<-o> <file>]
+
+=head1 CODE SYNOPSIS
+
+    my $results=$ixchel->action(action=>'suricata_extract_submit_config', opts=>{w=>1});
+
+    if ($results->{ok}) {
+        print $results->{filled_in};
+    }else{
+        die('Action errored... '.joined("\n", @{$results->{errors}}));
+    }
 
 =head1 DESCRIPTION
 
@@ -41,53 +52,18 @@ File to write the out to if -w is specified.
 
 Default :: /usr/local/etc/suricata_extract_submit.ini
 
+=head1 RESULT HASH REF
+
+    .errors :: A array of errors encountered.
+    .status_text :: A string description of what was done and the results.
+    .ok :: Set to zero if any of the above errored.
+    .filled_in :: The filled in template.
+
 =cut
 
-sub new {
-	my ( $empty, %opts ) = @_;
+sub new_extra { }
 
-	my $self = {
-		config => {},
-		vars   => {},
-		arggv  => [],
-		opts   => {},
-	};
-	bless $self;
-
-	if ( defined( $opts{config} ) ) {
-		$self->{config} = $opts{config};
-	}
-
-	if ( defined( $opts{t} ) ) {
-		$self->{t} = $opts{t};
-	} else {
-		die('$opts{t} is undef');
-	}
-
-	if ( defined( $opts{share_dir} ) ) {
-		$self->{share_dir} = $opts{share_dir};
-	}
-
-	if ( defined( $opts{opts} ) ) {
-		$self->{opts} = \%{ $opts{opts} };
-	}
-
-	if ( defined( $opts{argv} ) ) {
-		$self->{argv} = $opts{argv};
-	}
-
-	if ( defined( $opts{vars} ) ) {
-		$self->{vars} = $opts{vars};
-	}
-
-	if ( defined( $opts{ixchel} ) ) {
-		$self->{ixchel} = $opts{ixchel};
-	}
-
-	return $self;
-} ## end sub new
-
-sub action {
+sub action_extra {
 	my $self = $_[0];
 
 	# set the default output for -o if not defined
@@ -112,17 +88,28 @@ sub action {
 		);
 	};
 	if ($@) {
-		die( 'Filling in the template failed... ' . $@ );
+		$self->status_add( status => 'Failed to fill out template suricata_extract_submit ... ' . $@, error => 1 );
+		return undef;
 	}
 
-	if ( $self->{opts}{w} ) {
-		write_file( $self->{opts}{o}, $filled_in );
-	} else {
+	$self->{results}{filled_in} = $filled_in;
+
+	if ( !$self->{opts}{np} ) {
 		print $filled_in;
 	}
 
-	return $filled_in;
-} ## end sub action
+	if ( $self->{opts}{w} ) {
+		eval { write_file( $self->{opts}{o}, $filled_in ); };
+		if ($@) {
+			$self->status_add(
+				status => 'Failed to write out filled in template to "' . $self->{opts}{o} . '" ... ' . $@,
+				error  => 1
+			);
+		}
+	}
+
+	return undef;
+} ## end sub action_extra
 
 sub short {
 	return 'Generates the config file for suricata_extract_submit.';
